@@ -205,10 +205,14 @@ class RawTextRfcWriter(BaseRfcWriter):
             depth = item.level - 1
             if depth < 0 or self.pis.get('tocindent', 'yes') == 'no':
                 depth = 0
+            # Prepend appendix at first level
+            if item.level == 1 and item.appendix:
+                counter = "Appendix " + counter
             bullet = ' ' * (depth * indent_scale) + counter
             indent = 3
             sub_indent = indent + len(bullet)
-            lines = textwrap.wrap(bullet + item.title, self.width,
+            lines = textwrap.wrap(bullet + item.title, 
+                                  self.width - len(str(item.page)) + 1,
                                   initial_indent=' ' * indent,
                                   subsequent_indent=' ' * sub_indent)
             if paging:
@@ -589,15 +593,16 @@ class RawTextRfcWriter(BaseRfcWriter):
                         initials = initials + '.'
                     if j == len(authors) - 1 and len(authors) > 1:
                         # Last author is rendered in reverse
-                        refstring.append(' and ' + initials + ' ' + \
-                                         surname + ', ')
+                        refstring.append('and ' + initials + ' ' + \
+                                         surname)
                     else:
                         refstring.append(surname + ', ' + initials)
-                        if j != len(authors) - 2:
-                            # No comma before 'and'
-                            refstring.append(', ')
                     if author.attrib.get('role', '') == 'editor':
-                        refstring.append('Ed., ')
+                        refstring.append(', Ed.')
+                    if len(authors) == 2 and j == 0:
+                        refstring.append(' ')
+                    else:
+                        refstring.append(', ')
                 elif organization is not None and organization.text:
                     # Use organization instead of name
                     refstring.append(organization.text + ', ')
